%               FILE DESCRIBING THE NSCAT 50 km LEVEL 2.0 DATASET / ACCESS

%  nscatlow20.m v1.0 1998/11/30         pdh 
%  nscatlow20.m v1.1 1999/1/12          pdh


% FUNCTIONS -- REQUIRED
GetFunctionName = 'gnsc20l';
% FUNCTIONS -- OPTIONAL

% VARIABLES -- OPTIONAL

% Server:
Server = 'http://dods.jpl.nasa.gov/dods-bin/nph-hdf/pub/ocean_wind/nscat/data/L20';
Time = [1966+259/366 1997+180/365];

% VARIABLES -- REQUIRED
LonRange = [0.0 360.0];
LatRange =  [-75.0 75.0];
TimeRange = [1996+259/366 1997+180/365];
DepthRange = [0 0];
DepthUnits = '';
% Some archives have 50km data, some 25km.
% This is for 50km data.
  Resolution = 50.0; 
DataName = 'Wind - JPL Level 2 NSCAT (50km) - JPL';
LongitudeName = 'WVC_Lon';
LatitudeName = 'WVC_Lat';
TimeName = ''; % Null tells getnscatlow20 to use pass time
DepthName = '';
numxtrackpts = 24;
compute_variables = ['U_Wind'; 'V_Wind'];
% COMPUTE_VARIABLES and DEPENDENCIES MUST BE SUBSETS OF SelectableVariables
% compute_variable dependencies:
cvdependencies1=str2mat('Wind_Speed','Wind_Dir');
cvdependencies2=str2mat('Wind_Speed','Wind_Dir');
 
 SelectableVariables = str2mat('U_Wind','V_Wind','Wind_Speed',...
     'Wind_Dir','WVC_Quality_Flag','Num_Ambigs');
 DodsName = str2mat('U_Wind','V_Wind', ...
    'Wind_Speed', 'Wind_Dir','WVC_Quality_Flag','Num_Ambigs');

% note: DataNull is applied *before* scaling
DataNull = [nan; nan; -9000; nan; nan; nan; nan; nan; nan; nan];
DataScale = [nan nan; 0.0 0.01; 0.0 0.01; 0.0 1  ; 0.0   1; ...
             0.0   1; 0.0 0.01; 0.0 0.01; 0.0 1  ; 0.0   1]; 
DataRange = [nan nan; nan nan; nan nan; nan nan; nan nan; ...
             nan nan; nan nan; nan nan; nan nan; nan nan];


% COMMENTS

% The revised abstract is attached.  I made changes to
% each section.  Feel free to edit for consistency
% with other dataset abstracts.
%
% Rob [Raskin, at jpl, 11/25/97]
% Paul Hemenway @ uri, 11/30/98 for the low resolution Level 2.0 data.

Comments1 = sprintf('%s\n', ...
'            NASA/JPL Level 2 Low Resolution NSCAT (Ocean Winds)',...
' ',...
'NSCAT, the NASA Scatterometer, is a specialized microwave radar that measures',...
'the speed and direction of winds over the global ocean surface. The primary',...
'mission of NSCAT is to acquire all-weather, high-resolution measurements of',...
'near surface winds over the global oceans. The coverage is nearly global every',...
'2 days. The NSCAT Science Product (NSP) consists of several distinct data sets:',...
'Level 1.7 (colocated ocean sigma-0 data), Level 2.0 (vector winds in low or',...
'high resolution swaths) and Level 3.0 (gridded vector winds).',...
' ',...
'The Level 2 NSCAT low resolution product provides wind speed and direction',...
'averaged over 50 km "wind vector cells".  There are 24 wind vector cells in each',...
'cross-track row, with a small spatial gap between the leftmost and rightmost',...
'12 cells.  There are at most 820 rows per satellite revolution (or file). ',...
'In this data product, the wind direction ambiguities have been removed.',...
'A quality flag is also provided.',...
' ',...
'References:',...
'NSCAT Scatterometer Science Product, Levels 1.7, 2, 3 (JPL), Available at',...
'http://podaac-www.jpl.nasa.gov:2031/dataset_docs/nscat_25km.html');

Comments2 = sprintf('%s\n', ...
' Units:  Meters/Second (m/s)',...
' Scale Factor: 0.01',...
' Resolution: 50 km (spatial)',...
'             8 seconds (temporal)',...
' Accuracy:',...
'         Speed:     2 m/s (winds < 20 m/s)',...
'                    10%   (winds > 20 m/s)',...
'         Direction: 20 degrees',...
' Range:',...
'         Speed:     0 - 50 m/s',...
'         Direction: 0 - 359.99 degrees',...
' Time_Period_of_Content',...
'      Beginning_Date:1996/09/15',...
'      Ending_Date:1997/06/29',...
' Spatial_Domain',...
'      Bounding Coordinates',...
'           West Bounding Coordinate:0.0',...
'           East Bounding Coordinate:360.0',...
'           South Bounding Coordinate:-75 .0',...
'           North Bounding Coordinate:+75.0',...
' Point_of_Contact',...
'      Contact Person:RASKIN, ROB',...
'      Contact Position:Systems Engineer',...
'      Address            NASA',...
'            Jet Propulsion Laboratory',...
'            4800 Oak Grove',...
'            Pasadena, CA  91109',...
'      Telephone:(818) 306-6061',...
'      Electronic Mail Address:INTERNET > robert.raskin@jpl.nasa.gov',...
'      Contact Person:SGOUROS, TOM',...
'      Contact Position:Technical Support',...
'      Address',...
'            Graduate School of Oceanography',...
'            University of Rhode Island',...
'            South Ferry Road',...
'            Narragansett, Rhode Island  02882',...
'            USA',...
'      Electronic Mail Address:INTERNET > support@unidata.ucar.edu');

Comments = [Comments1 Comments2];


